@@ -343,6 +343,19 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "PDF has password mutiple of 32" do
+    let(:filename) { pdf_spec_file("encrypted_pdf_with_64_chars_string") }
+    let(:pass) { "8c24e855ef6f2eeabe9beb87478cef5ba14aa6e627364f3c7e2b1101bb791729" }
+
+    context "with the user pass" do
+      it "correctly extracts text" do
+        PDF::Reader.open(filename, :password => pass) do |reader|
+          expect(reader.page(1).text).to include("Dummy PDF file")
+        end
+      end
+    end
+  end
+
   context "encrypted_version1_revision2_40bit_rc4_user_pass_apples" do
     let(:filename) { pdf_spec_file("encrypted_version1_revision2_40bit_rc4_user_pass_apples") }
 
@@ -1423,7 +1436,7 @@ describe PDF::Reader, "integration specs" do
   context "PDF with page rotation of 270 degrees followed by matrix transformations to undo it" do
     let(:filename) { pdf_spec_file("rotate-then-undo") }
     let(:text) {
-      "This page uses matrix transformations to print text   sideways, " +
+      "This page uses matrix transformations to print text sideways, " +
       "then has a Rotate key to fix it"
     }
 
@@ -1634,7 +1647,7 @@ describe PDF::Reader, "integration specs" do
     it "extracts text correctly" do
       PDF::Reader.open(filename) do |reader|
         page = reader.page(1)
-        expect(page.text).to include("This PDF ha  sRotate:90 in the page")
+        expect(page.text).to include("This PDF has Rotate:90 in the page")
         expect(page.text).to include("metadata to get a landscape layout")
         expect(page.text).to include("and text in bottom right quadrant")
       end
@@ -1814,4 +1827,24 @@ describe PDF::Reader, "integration specs" do
       end
     end
   end
+
+  context "PDF with a ToUnicode of the wrong type" do
+    let(:filename) { pdf_spec_file("tounicode-wrong-type") }
+
+    it "succesfully extracts text" do
+      PDF::Reader.open(filename) do |reader|
+        expect(reader.page(1).text).to start_with("This file has an invalid ToUnicode entry.")
+      end
+    end
+  end
+
+  context "PDF with a ToUnicode of the wrong type and behind an indirect object" do
+    let(:filename) { pdf_spec_file("tounicode-wrong-type-indirect") }
+
+    it "succesfully extracts text" do
+      PDF::Reader.open(filename) do |reader|
+        expect(reader.page(1).text).to start_with("This file has an invalid ToUnicode entry.")
+      end
+    end
+  end
 end
